@@ -25,6 +25,9 @@ class Receiver:
             self.PARASUT_REGISTRY: str = env["PARASUT_REGISTRY"]
             self.PARASUT_BASE_DIR: str = env["PARASUT_BASE_DIR"]
             self.PARASUT_CLI_TEXT_EDITOR: str = env["PARASUT_CLI_TEXT_EDITOR"]
+            self.PARASUT_NPM_USERNAME: str = env["PARASUT_NPM_USERNAME"]
+            self.PARASUT_NPM_PASSWORD: str = env["PARASUT_NPM_PASSWORD"]
+            self.PARASUT_NPM_EMAIL: str = env["PARASUT_NPM_EMAIL"]
             # server
             self.SERVER_RUBY_V: str = env["PARASUT_SERVER_RUBY_V"]
             self.SERVER_DIR: str = env["PARASUT_SERVER_DIR"]
@@ -75,6 +78,9 @@ class Receiver:
         self._tmux_server: Server
         self._tmux_session_parasut_ws_setup: Session
         self._tmux_session_parasut_ws_editor: Session
+        self._third_party_packages: Dict[str, str] = dict(
+            npm_cli_login="npm-cli-login",
+        )
         self._dep_versions: Dict[str, Dict[str, Any]] = dict(
             ui_library=dict(linked=False, value=""),
             shared_logic=dict(linked=False, value=""),
@@ -86,16 +92,24 @@ class Receiver:
         self._core_commands: Dict[str, str] = dict(
             source_asdf="source ~/.asdf/asdf.sh",
             ember_release="ember release",
-            npm_set_parasut_registry=f"npm config set registry {self.PARASUT_REGISTRY}",
-            npm_login="npm login",
-            npm_publish="npm publish",
-            npm_delete_registry="npm config delete registry",
             git_change_branch_master="git checkout master",
             git_change_branch_develop="git checkout develop",
             git_fetch_all="git fetch --all",
             git_pull_origin_master="git pull origin master",
             git_pull_origin_develop="git pull origin develop",
         )
+        self._npm_release_commands: Dict[str, str] = dict(
+            npm_set_parasut_registry=f"npm config set registry {self.PARASUT_REGISTRY}",
+            npm_login="npm login",
+            npm_publish="npm publish",
+            npm_delete_registry="npm config delete registry",
+        )
+        self._npm_auto_release_commands: Dict[str, str] = dict(
+            npm_set_parasut_registry=f"npm config set registry {self.PARASUT_REGISTRY}",
+            npm_login=f"npm-cli-login login -u {self.PARASUT_NPM_USERNAME} -p {self.PARASUT_NPM_PASSWORD} -e {self.PARASUT_NPM_EMAIL} -r {self.PARASUT_REGISTRY}",
+            npm_publish="npm publish --verbose",
+            npm_delete_registry="npm config delete registry",
+        )
         self._worker_commands: Dict[str, str] = dict(
             launch_server_worker="foreman start -m 'worker=1, shoryuken=1, sidekiq_mikro_outbound=1, sidekiq_mikro_outbound=1'",  # noqa: E501
             launch_e_doc_broker_worker="foreman start -m 'shoryuken=1, sidekiq_inbound=1, sidekiq_outbound=1, sidekiq_send=1, sidekiq_fetch_ubl=1, sidekiq_storage=1, sidekiq_other=1, sidekiq_migrations=1'",  # noqa: E501
@@ -252,10 +266,25 @@ class Receiver:
                 self._core_commands["git_pull_origin_master"],
                 self._core_commands["git_fetch_all"],
                 self._core_commands["ember_release"],
-                self._core_commands["npm_set_parasut_registry"],
-                self._core_commands["npm_login"],
-                self._core_commands["npm_publish"],
-                self._core_commands["npm_delete_registry"],
+                self._npm_release_commands["npm_set_parasut_registry"],
+                self._npm_release_commands["npm_login"],
+                self._npm_release_commands["npm_publish"],
+                self._npm_release_commands["npm_delete_registry"],
+            ]
+        )
+        self._task_auto_release_shared_logic = " && ".join(
+            [
+                self._core_commands["source_asdf"],
+                self._shared_logic_commands["choose_yarn_version"],
+                self._shared_logic_commands["choose_node_version"],
+                self._core_commands["git_change_branch_master"],
+                self._core_commands["git_pull_origin_master"],
+                self._core_commands["git_fetch_all"],
+                self._core_commands["ember_release"],
+                self._npm_auto_release_commands["npm_set_parasut_registry"],
+                self._npm_auto_release_commands["npm_login"],
+                self._npm_auto_release_commands["npm_publish"],
+                self._npm_auto_release_commands["npm_delete_registry"],
             ]
         )
         self._task_run_trinity = " && ".join(
@@ -283,10 +312,25 @@ class Receiver:
                 self._core_commands["git_pull_origin_develop"],
                 self._core_commands["git_fetch_all"],
                 self._core_commands["ember_release"],
-                self._core_commands["npm_set_parasut_registry"],
-                self._core_commands["npm_login"],
-                self._core_commands["npm_publish"],
-                self._core_commands["npm_delete_registry"],
+                self._npm_release_commands["npm_set_parasut_registry"],
+                self._npm_release_commands["npm_login"],
+                self._npm_release_commands["npm_publish"],
+                self._npm_release_commands["npm_delete_registry"],
+            ]
+        )
+        self._task_auto_release_ui_library = " && ".join(
+            [
+                self._core_commands["source_asdf"],
+                self._ui_library_commands["choose_yarn_version"],
+                self._ui_library_commands["choose_node_version"],
+                self._core_commands["git_change_branch_develop"],
+                self._core_commands["git_pull_origin_develop"],
+                self._core_commands["git_fetch_all"],
+                self._core_commands["ember_release"],
+                self._npm_auto_release_commands["npm_set_parasut_registry"],
+                self._npm_auto_release_commands["npm_login"],
+                self._npm_auto_release_commands["npm_publish"],
+                self._npm_auto_release_commands["npm_delete_registry"],
             ]
         )
         self._task_run_client = " && ".join(
@@ -373,18 +417,47 @@ class Receiver:
         except Exception as e:
             print(e)
 
-    def release_repo(self, repo_name: str) -> None:
-        base_path: str = self._find_repo_path(repo_name)
+    def release_repo(
+        self, target_repo: str, show_output: bool, auto_login: bool
+    ) -> None:
+        target_path: str = self._find_repo_path(target_repo)
 
-        self._change_directory(base_path)
+        self._check_npm_package_installed(self._third_party_packages["npm_cli_login"])
+        self._change_directory(target_path)
 
         try:
-            if repo_name == "shared-logic":
-                self._run_process([self._task_release_shared_logic], show_output=True)
-            elif repo_name == "ui-library":
-                self._run_process([self._task_release_ui_library], show_output=True)
+            if target_repo == "shared-logic":
+                if auto_login is True:
+                    self._run_process(
+                        [self._task_auto_release_shared_logic], show_output=show_output
+                    )
+                    if show_output is False:
+                        console.print(":ok_hand: Target repo has been released.")
+                else:
+                    self._run_process(
+                        [self._task_release_shared_logic], show_output=show_output
+                    )
+                    if show_output is False:
+                        console.print(":ok_hand: Target repo has been released.")
+            elif target_repo == "ui-library":
+                if auto_login is True:
+                    self._run_process(
+                        [self._task_auto_release_ui_library], show_output=show_output
+                    )
+                    if show_output is False:
+                        console.print(":ok_hand: Target repo has been released.")
+                else:
+                    self._run_process(
+                        [self._task_release_ui_library], show_output=show_output
+                    )
+                    if show_output is False:
+                        console.print(":ok_hand: Target repo has been released.")
         except KeyboardInterrupt:
-            pass
+            console.print(
+                ":pile_of_poo: You interrupted process. \
+                          Manually check your demand steps."
+            )
+            sys.exit(0)
         except Exception as e:
             print(e)
 
@@ -753,15 +826,26 @@ class Receiver:
     def get_pkg_version(self) -> None:
         print(parasut_cli.__version__)
 
-    def _run_process(self, tasks: List[str], show_output=False):
+    def _check_npm_package_installed(self, pkg_name: str):
+        command = f"npm list -g --depth=0 | grep {pkg_name}"
+
+        try:
+            output = self._run_process(tasks=[command], show_output=False).stdout
+        except subprocess.CalledProcessError:
+            console.print(f":thumbs_down: You must install '{pkg_name}' package.")
+            sys.exit(0)
+
+    def _run_process(self, tasks: List[str], show_output: bool):
         if show_output is False:
             with console.status("[bold green] Working on process..."):
                 for task in tasks:
                     result = subprocess.run(
                         ["/bin/zsh", "-c", f"{task}"],
                         capture_output=True,
+                        text=True,
                     )
                     result.check_returncode()
+                    return result
         else:
             for task in tasks:
                 subprocess.run(
